excel

package module
v0.0.0-...-23a7608 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: MIT Imports: 10 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var (
	AvatarCodexExcelConfigData      []*AvatarCodex
	AvatarCurveExcelConfigData      []*Curve
	AvatarExcelConfigData           []*Avatar
	AvatarPromoteExcelConfigData    []*AvatarPromote
	AvatarSkillDepotExcelConfigData []*AvatarSkillDepot
	AvatarSkillExcelConfigData      []*AvatarSkill
	AvatarTalentExcelConfigData     []*AvatarTalent
	ProudSkillExcelConfigData       []*ProudSkill
)
var (
	Languages = []string{"CHS", "CHT", "DE", "EN", "ES", "FR", "ID", "IT", "JP", "KR", "PT", "RU", "TH", "TR", "VI"}

	ManualTextMapConfigData []*ManualTextMap
)
var (
	MonsterCurveExcelConfigData    []*Curve
	MonsterDescribeExcelConfigData []*MonsterDescribe
	MonsterExcelConfigData         []*Monster
)
var (
	ReliquaryAffixExcelConfigData    []*ReliquaryAffix
	ReliquaryCodexExcelConfigData    []*ReliquaryCodex
	ReliquaryExcelConfigData         []*Reliquary
	ReliquaryLevelExcelConfigData    []*ReliquaryLevel
	ReliquaryMainPropExcelConfigData []*ReliquaryMainProp
	ReliquarySetExcelConfigData      []*ReliquarySet
)
var (
	WeaponCodexExcelConfigData   []*WeaponCodex
	WeaponCurveExcelConfigData   []*Curve
	WeaponExcelConfigData        []*Weapon
	WeaponPromoteExcelConfigData []*WeaponPromote
)
var AttackAttenuationExcelConfigData []*AttackAttenuation
var ElementCoeffExcelConfigData []*ElementCoeff
var EquipAffixExcelConfigData []*EquipAffix
var FetterInfoExcelConfigData []*FetterInfo
var GadgetExcelConfigData []*Gadget
var HomeWorldFurnitureExcelConfigData []*HomeWorldFurniture
var MaterialExcelConfigData []*Material

Functions

func ElementTypeStrings

func ElementTypeStrings() []string

ElementTypeStrings returns a slice of all String values of the enum

func EquipTypeStrings

func EquipTypeStrings() []string

EquipTypeStrings returns a slice of all String values of the enum

func FightPropStrings

func FightPropStrings() []string

FightPropStrings returns a slice of all String values of the enum

func Filter

func Filter[S ~[]E, E any](s S, f func(E) bool) S

func Find

func Find[S ~[]E, E any](s S, f func(E) bool) E

func GrowCurveTypeStrings

func GrowCurveTypeStrings() []string

GrowCurveTypeStrings returns a slice of all String values of the enum

func ItemTypeStrings

func ItemTypeStrings() []string

ItemTypeStrings returns a slice of all String values of the enum

func LoadResources

func LoadResources(cfg LoaderConfig) error

func PlayerPropStrings

func PlayerPropStrings() []string

PlayerPropStrings returns a slice of all String values of the enum

func ReactionTypeStrings

func ReactionTypeStrings() []string

ReactionTypeStrings returns a slice of all String values of the enum

func Slug

func Slug(s string) string

func SlugLower

func SlugLower(s string) string

func WeaponTypeStrings

func WeaponTypeStrings() []string

WeaponTypeStrings returns a slice of all String values of the enum

Types

type AttackAttenuation

type AttackAttenuation struct {
	Group              string
	ResetCycle         float64
	DurabilitySequence []float64
	EnbreakSequence    []float64
	DamageSequence     []float64
}

func FindAttackAttenuation

func FindAttackAttenuation(group string) *AttackAttenuation

type Avatar

type Avatar struct {
	Creature
	UseType             string // AvatarUseType
	BodyType            string // BodyType
	IconName            string
	SideIconName        string
	QualityType         string // QualityType
	ChargeEfficiency    float64
	IsRangeAttack       bool
	WeaponType          WeaponType
	ImageName           string
	SkillDepotId        uint32
	StaminaRecoverSpeed float64
	CandSkillDepotIds   []uint32
	DescTextMapHash     TextMapHash
	AvatarIdentityType  string // AvatarIdentityType
	AvatarPromoteId     uint32
	FeatureTagGroupId   uint32
	InfoDescTextMapHash TextMapHash
}

func FindAvatar

func FindAvatar(id uint32) *Avatar

func (*Avatar) Codex

func (a *Avatar) Codex() *AvatarCodex

func (*Avatar) Curve

func (a *Avatar) Curve(level uint32) *Curve

func (*Avatar) FetterInfo

func (a *Avatar) FetterInfo() *FetterInfo

func (*Avatar) Promote

func (a *Avatar) Promote(level uint32) *AvatarPromote

func (*Avatar) SkillDepot

func (a *Avatar) SkillDepot() *AvatarSkillDepot

type AvatarCodex

type AvatarCodex struct {
	AvatarId uint32
}

func (*AvatarCodex) Avatar

func (a *AvatarCodex) Avatar() *Avatar

type AvatarPromote

type AvatarPromote struct {
	AvatarPromoteId     uint32
	PromoteLevel        uint32
	ScoinCost           uint32
	CostItems           []*IdCount
	UnlockMaxLevel      uint32
	AddProps            []*PropValue
	RequiredPlayerLevel uint32
}

type AvatarSkill

type AvatarSkill struct {
	Id                 uint32
	NameTextMapHash    TextMapHash
	AbilityName        string
	DescTextMapHash    TextMapHash
	SkillIcon          string
	IsRanged           bool
	CDTime             float64
	IgnoreCDMinusRatio bool
	CostStamina        float64
	CostElemType       ElementType
	CostElemVal        float64
	MaxChargeNum       int
	TriggerID          int
	ProudSkillGroupId  uint32
	CDSlot             uint32
	SpecialEnergyMax   uint32
	SpecialEnergyMin   uint32
	SpecialEnergyType  string
}

func FindSkill

func FindSkill(id uint32) *AvatarSkill

func (*AvatarSkill) Name

func (a *AvatarSkill) Name() string

func (*AvatarSkill) ProudSkill

func (a *AvatarSkill) ProudSkill(level uint32) *ProudSkill

type AvatarSkillDepot

type AvatarSkillDepot struct {
	Id                      uint32
	EnergySkill             uint32
	Skills                  []uint32
	SubSkills               []uint32
	AttackModeSkill         uint32
	Talents                 []uint32
	TalentStarName          string
	InherentProudSkillOpens []*ProudSkillOpen
	SkillDepotAbilityGroup  string
	ArkheType               string `json:"__exp_arkheType"` // custom field
}

func FindSkillDepot

func FindSkillDepot(id uint32) *AvatarSkillDepot

type AvatarTalent

type AvatarTalent struct {
	BaseTalent
	TalentId          uint32
	NameTextMapHash   TextMapHash
	DescTextMapHash   TextMapHash
	Icon              string
	PrevTalent        uint32
	MainCostItemId    uint32
	MainCostItemCount uint32
}

func FindTalent

func FindTalent(id uint32) *AvatarTalent

func (*AvatarTalent) Name

func (a *AvatarTalent) Name() string

func (*AvatarTalent) Prev

func (a *AvatarTalent) Prev() *AvatarTalent

type BaseTalent

type BaseTalent struct {
	OpenConfig string
	AddProps   []*PropValue
	ParamList  []float64
}

type Creature

type Creature struct {
	Entity
	HpBase          float64
	AttackBase      float64
	DefenseBase     float64
	Critical        float64
	CriticalHurt    float64
	FireSubHurt     float64
	GrassSubHurt    float64
	WaterSubHurt    float64
	ElecSubHurt     float64
	WindSubHurt     float64
	IceSubHurt      float64
	RockSubHurt     float64
	PropGrowCurves  []*FightPropGrow
	ElementMastery  float64
	PhysicalSubHurt float64
}

type Curve

type Curve struct {
	Level      uint32
	CurveInfos []*GrowCurveInfo
}

func FindCurveData

func FindCurveData(list []*Curve, level uint32) *Curve

func (*Curve) Type

func (c *Curve) Type(typ GrowCurveType) (string, float64)

type ElementCoeff

type ElementCoeff struct {
	Level                uint32
	CrashCo              float64
	ElementLevelCo       float64
	PlayerElementLevelCo float64
	PlayerShieldLevelCo  float64
}

func FindElementCoeff

func FindElementCoeff(level uint32) *ElementCoeff

type ElementType

type ElementType uint32
const (
	ElementNone               ElementType = 0
	ElementFire               ElementType = 1
	ElementWater              ElementType = 2
	ElementGrass              ElementType = 3
	ElementElectric           ElementType = 4
	ElementIce                ElementType = 5
	ElementFrozen             ElementType = 6
	ElementWind               ElementType = 7
	ElementRock               ElementType = 8
	ElementAntiFire           ElementType = 9
	ElementVehicleMuteIce     ElementType = 10
	ElementMushroom           ElementType = 11
	ElementOverdose           ElementType = 12
	ElementWood               ElementType = 13
	ElementLiquidPhlogiston   ElementType = 14
	ElementSolidPhlogiston    ElementType = 15
	ElementSolidifyPhlogiston ElementType = 16
)

func ElementTypeString

func ElementTypeString(s string) (ElementType, error)

ElementTypeString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func ElementTypeValues

func ElementTypeValues() []ElementType

ElementTypeValues returns all values of the enum

func (ElementType) IsAElementType

func (i ElementType) IsAElementType() bool

IsAElementType returns "true" if the value is listed in the enum definition. "false" otherwise

func (ElementType) MarshalJSON

func (i ElementType) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for ElementType

func (ElementType) MarshalText

func (i ElementType) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for ElementType

func (ElementType) String

func (i ElementType) String() string

func (*ElementType) UnmarshalJSON

func (i *ElementType) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for ElementType

func (*ElementType) UnmarshalText

func (i *ElementType) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for ElementType

type Entity

type Entity struct {
	Id              uint32
	NameTextMapHash TextMapHash
	CampID          uint32
}

func (*Entity) Name

func (e *Entity) Name() string

type EquipAffix

type EquipAffix struct {
	BaseTalent
	AffixId         uint32
	Id              uint32
	Level           uint32
	NameTextMapHash TextMapHash
	DescTextMapHash TextMapHash
}

func FindEquipAffix

func FindEquipAffix(id, level uint32) *EquipAffix

func (*EquipAffix) Name

func (e *EquipAffix) Name() string

type EquipType

type EquipType uint32
const (
	EQUIP_NONE EquipType = iota
	EQUIP_BRACER
	EQUIP_NECKLACE
	EQUIP_SHOES
	EQUIP_RING
	EQUIP_DRESS
	EQUIP_WEAPON
)

func EquipTypeString

func EquipTypeString(s string) (EquipType, error)

EquipTypeString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func EquipTypeValues

func EquipTypeValues() []EquipType

EquipTypeValues returns all values of the enum

func (EquipType) IsAEquipType

func (i EquipType) IsAEquipType() bool

IsAEquipType returns "true" if the value is listed in the enum definition. "false" otherwise

func (EquipType) MarshalJSON

func (i EquipType) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for EquipType

func (EquipType) MarshalText

func (i EquipType) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for EquipType

func (EquipType) String

func (i EquipType) String() string

func (*EquipType) UnmarshalJSON

func (i *EquipType) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for EquipType

func (*EquipType) UnmarshalText

func (i *EquipType) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for EquipType

type FetterInfo

type FetterInfo struct {
	FetterId                            uint32
	AvatarId                            uint32
	InfoBirthMonth                      uint32
	InfoBirthDay                        uint32
	AvatarNativeTextMapHash             TextMapHash
	AvatarVisionBeforTextMapHash        TextMapHash
	AvatarConstellationBeforTextMapHash TextMapHash
	AvatarTitleTextMapHash              TextMapHash
	AvatarDetailTextMapHash             TextMapHash
	AvatarAssocType                     string // AssocType
	CvChineseTextMapHash                TextMapHash
	CvJapaneseTextMapHash               TextMapHash
	CvEnglishTextMapHash                TextMapHash
	CvKoreanTextMapHash                 TextMapHash
	AvatarVisionAfterTextMapHash        TextMapHash
	AvatarConstellationAfterTextMapHash TextMapHash
}

func (*FetterInfo) Avatar

func (f *FetterInfo) Avatar() *Avatar

type FightProp

type FightProp uint32
const (
	FIGHT_PROP_NONE                                       FightProp = 0
	FIGHT_PROP_BASE_HP                                    FightProp = 1
	FIGHT_PROP_HP                                         FightProp = 2
	FIGHT_PROP_HP_PERCENT                                 FightProp = 3
	FIGHT_PROP_BASE_ATTACK                                FightProp = 4
	FIGHT_PROP_ATTACK                                     FightProp = 5
	FIGHT_PROP_ATTACK_PERCENT                             FightProp = 6
	FIGHT_PROP_BASE_DEFENSE                               FightProp = 7
	FIGHT_PROP_DEFENSE                                    FightProp = 8
	FIGHT_PROP_DEFENSE_PERCENT                            FightProp = 9
	FIGHT_PROP_BASE_SPEED                                 FightProp = 10
	FIGHT_PROP_SPEED_PERCENT                              FightProp = 11
	FIGHT_PROP_HP_MP_PERCENT                              FightProp = 12
	FIGHT_PROP_ATTACK_MP_PERCENT                          FightProp = 13
	FIGHT_PROP_CRITICAL                                   FightProp = 20
	FIGHT_PROP_ANTI_CRITICAL                              FightProp = 21
	FIGHT_PROP_CRITICAL_HURT                              FightProp = 22
	FIGHT_PROP_CHARGE_EFFICIENCY                          FightProp = 23
	FIGHT_PROP_ADD_HURT                                   FightProp = 24
	FIGHT_PROP_SUB_HURT                                   FightProp = 25
	FIGHT_PROP_HEAL_ADD                                   FightProp = 26
	FIGHT_PROP_HEALED_ADD                                 FightProp = 27
	FIGHT_PROP_ELEMENT_MASTERY                            FightProp = 28
	FIGHT_PROP_PHYSICAL_SUB_HURT                          FightProp = 29
	FIGHT_PROP_PHYSICAL_ADD_HURT                          FightProp = 30
	FIGHT_PROP_DEFENCE_IGNORE_RATIO                       FightProp = 31
	FIGHT_PROP_DEFENCE_IGNORE_DELTA                       FightProp = 32
	FIGHT_PROP_FIRE_ADD_HURT                              FightProp = 40
	FIGHT_PROP_ELEC_ADD_HURT                              FightProp = 41
	FIGHT_PROP_WATER_ADD_HURT                             FightProp = 42
	FIGHT_PROP_GRASS_ADD_HURT                             FightProp = 43
	FIGHT_PROP_WIND_ADD_HURT                              FightProp = 44
	FIGHT_PROP_ROCK_ADD_HURT                              FightProp = 45
	FIGHT_PROP_ICE_ADD_HURT                               FightProp = 46
	FIGHT_PROP_HIT_HEAD_ADD_HURT                          FightProp = 47
	FIGHT_PROP_FIRE_SUB_HURT                              FightProp = 50
	FIGHT_PROP_ELEC_SUB_HURT                              FightProp = 51
	FIGHT_PROP_WATER_SUB_HURT                             FightProp = 52
	FIGHT_PROP_GRASS_SUB_HURT                             FightProp = 53
	FIGHT_PROP_WIND_SUB_HURT                              FightProp = 54
	FIGHT_PROP_ROCK_SUB_HURT                              FightProp = 55
	FIGHT_PROP_ICE_SUB_HURT                               FightProp = 56
	FIGHT_PROP_EFFECT_HIT                                 FightProp = 60
	FIGHT_PROP_EFFECT_RESIST                              FightProp = 61
	FIGHT_PROP_FREEZE_RESIST                              FightProp = 62
	FIGHT_PROP_DIZZY_RESIST                               FightProp = 64
	FIGHT_PROP_FREEZE_SHORTEN                             FightProp = 65
	FIGHT_PROP_DIZZY_SHORTEN                              FightProp = 67
	FIGHT_PROP_MAX_FIRE_ENERGY                            FightProp = 70
	FIGHT_PROP_MAX_ELEC_ENERGY                            FightProp = 71
	FIGHT_PROP_MAX_WATER_ENERGY                           FightProp = 72
	FIGHT_PROP_MAX_GRASS_ENERGY                           FightProp = 73
	FIGHT_PROP_MAX_WIND_ENERGY                            FightProp = 74
	FIGHT_PROP_MAX_ICE_ENERGY                             FightProp = 75
	FIGHT_PROP_MAX_ROCK_ENERGY                            FightProp = 76
	FIGHT_PROP_MAX_SPECIAL_ENERGY                         FightProp = 77
	FIGHT_PROP_START_SPECIAL_ENERGY                       FightProp = 78
	FIGHT_PROP_SKILL_CD_MINUS_RATIO                       FightProp = 80
	FIGHT_PROP_SHIELD_COST_MINUS_RATIO                    FightProp = 81
	FIGHT_PROP_CUR_FIRE_ENERGY                            FightProp = 1000
	FIGHT_PROP_CUR_ELEC_ENERGY                            FightProp = 1001
	FIGHT_PROP_CUR_WATER_ENERGY                           FightProp = 1002
	FIGHT_PROP_CUR_GRASS_ENERGY                           FightProp = 1003
	FIGHT_PROP_CUR_WIND_ENERGY                            FightProp = 1004
	FIGHT_PROP_CUR_ICE_ENERGY                             FightProp = 1005
	FIGHT_PROP_CUR_ROCK_ENERGY                            FightProp = 1006
	FIGHT_PROP_CUR_SPECIAL_ENERGY                         FightProp = 1007
	FIGHT_PROP_CUR_HP                                     FightProp = 1010
	FIGHT_PROP_MAX_HP                                     FightProp = 2000
	FIGHT_PROP_CUR_ATTACK                                 FightProp = 2001
	FIGHT_PROP_CUR_DEFENSE                                FightProp = 2002
	FIGHT_PROP_CUR_SPEED                                  FightProp = 2003
	FIGHT_PROP_CUR_HP_DEBTS                               FightProp = 2004
	FIGHT_PROP_CUR_HP_PAID_DEBTS                          FightProp = 2005
	FIGHT_PROP_CUR_NATLAN_HP                              FightProp = 2006
	FIGHT_PROP_NONEXTRA_ATTACK                            FightProp = 3000
	FIGHT_PROP_NONEXTRA_DEFENSE                           FightProp = 3001
	FIGHT_PROP_NONEXTRA_CRITICAL                          FightProp = 3002
	FIGHT_PROP_NONEXTRA_ANTI_CRITICAL                     FightProp = 3003
	FIGHT_PROP_NONEXTRA_CRITICAL_HURT                     FightProp = 3004
	FIGHT_PROP_NONEXTRA_CHARGE_EFFICIENCY                 FightProp = 3005
	FIGHT_PROP_NONEXTRA_ELEMENT_MASTERY                   FightProp = 3006
	FIGHT_PROP_NONEXTRA_PHYSICAL_SUB_HURT                 FightProp = 3007
	FIGHT_PROP_NONEXTRA_FIRE_ADD_HURT                     FightProp = 3008
	FIGHT_PROP_NONEXTRA_ELEC_ADD_HURT                     FightProp = 3009
	FIGHT_PROP_NONEXTRA_WATER_ADD_HURT                    FightProp = 3010
	FIGHT_PROP_NONEXTRA_GRASS_ADD_HURT                    FightProp = 3011
	FIGHT_PROP_NONEXTRA_WIND_ADD_HURT                     FightProp = 3012
	FIGHT_PROP_NONEXTRA_ROCK_ADD_HURT                     FightProp = 3013
	FIGHT_PROP_NONEXTRA_ICE_ADD_HURT                      FightProp = 3014
	FIGHT_PROP_NONEXTRA_FIRE_SUB_HURT                     FightProp = 3015
	FIGHT_PROP_NONEXTRA_ELEC_SUB_HURT                     FightProp = 3016
	FIGHT_PROP_NONEXTRA_WATER_SUB_HURT                    FightProp = 3017
	FIGHT_PROP_NONEXTRA_GRASS_SUB_HURT                    FightProp = 3018
	FIGHT_PROP_NONEXTRA_WIND_SUB_HURT                     FightProp = 3019
	FIGHT_PROP_NONEXTRA_ROCK_SUB_HURT                     FightProp = 3020
	FIGHT_PROP_NONEXTRA_ICE_SUB_HURT                      FightProp = 3021
	FIGHT_PROP_NONEXTRA_SKILL_CD_MINUS_RATIO              FightProp = 3022
	FIGHT_PROP_NONEXTRA_SHIELD_COST_MINUS_RATIO           FightProp = 3023
	FIGHT_PROP_NONEXTRA_PHYSICAL_ADD_HURT                 FightProp = 3024
	FIGHT_PROP_BASE_ELEM_REACT_CRITICAL                   FightProp = 3045
	FIGHT_PROP_BASE_ELEM_REACT_CRITICAL_HURT              FightProp = 3046
	FIGHT_PROP_ELEM_REACT_CRITICAL                        FightProp = 3025
	FIGHT_PROP_ELEM_REACT_CRITICAL_HURT                   FightProp = 3026
	FIGHT_PROP_ELEM_REACT_EXPLODE_CRITICAL                FightProp = 3027
	FIGHT_PROP_ELEM_REACT_EXPLODE_CRITICAL_HURT           FightProp = 3028
	FIGHT_PROP_ELEM_REACT_SWIRL_CRITICAL                  FightProp = 3029
	FIGHT_PROP_ELEM_REACT_SWIRL_CRITICAL_HURT             FightProp = 3030
	FIGHT_PROP_ELEM_REACT_ELECTRIC_CRITICAL               FightProp = 3031
	FIGHT_PROP_ELEM_REACT_ELECTRIC_CRITICAL_HURT          FightProp = 3032
	FIGHT_PROP_ELEM_REACT_SCONDUCT_CRITICAL               FightProp = 3033
	FIGHT_PROP_ELEM_REACT_SCONDUCT_CRITICAL_HURT          FightProp = 3034
	FIGHT_PROP_ELEM_REACT_BURN_CRITICAL                   FightProp = 3035
	FIGHT_PROP_ELEM_REACT_BURN_CRITICAL_HURT              FightProp = 3036
	FIGHT_PROP_ELEM_REACT_FROZENBROKEN_CRITICAL           FightProp = 3037
	FIGHT_PROP_ELEM_REACT_FROZENBROKEN_CRITICAL_HURT      FightProp = 3038
	FIGHT_PROP_ELEM_REACT_OVERGROW_CRITICAL               FightProp = 3039
	FIGHT_PROP_ELEM_REACT_OVERGROW_CRITICAL_HURT          FightProp = 3040
	FIGHT_PROP_ELEM_REACT_OVERGROW_FIRE_CRITICAL          FightProp = 3041
	FIGHT_PROP_ELEM_REACT_OVERGROW_FIRE_CRITICAL_HURT     FightProp = 3042
	FIGHT_PROP_ELEM_REACT_OVERGROW_ELECTRIC_CRITICAL      FightProp = 3043
	FIGHT_PROP_ELEM_REACT_OVERGROW_ELECTRIC_CRITICAL_HURT FightProp = 3044
)

func FightPropString

func FightPropString(s string) (FightProp, error)

FightPropString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func FightPropValues

func FightPropValues() []FightProp

FightPropValues returns all values of the enum

func (FightProp) IsAFightProp

func (i FightProp) IsAFightProp() bool

IsAFightProp returns "true" if the value is listed in the enum definition. "false" otherwise

func (FightProp) MarshalJSON

func (i FightProp) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for FightProp

func (FightProp) MarshalText

func (i FightProp) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for FightProp

func (FightProp) String

func (i FightProp) String() string

func (*FightProp) UnmarshalJSON

func (i *FightProp) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for FightProp

func (*FightProp) UnmarshalText

func (i *FightProp) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for FightProp

type FightPropGrow

type FightPropGrow struct {
	Type      FightProp
	GrowCurve GrowCurveType
}

type Gadget

type Gadget struct {
	Entity
	Type                    string // EntityType
	JsonName                string
	InteractNameTextMapHash TextMapHash
}

func FindGadget

func FindGadget(id uint32) *Gadget

type GrowCurveInfo

type GrowCurveInfo struct {
	Type  GrowCurveType
	Arith string // ArithType
	Value float64
}

type GrowCurveType

type GrowCurveType uint32
const (
	GROW_CURVE_NONE               GrowCurveType = 0
	GROW_CURVE_HP                 GrowCurveType = 1
	GROW_CURVE_ATTACK             GrowCurveType = 2
	GROW_CURVE_STAMINA            GrowCurveType = 3
	GROW_CURVE_STRIKE             GrowCurveType = 4
	GROW_CURVE_ANTI_STRIKE        GrowCurveType = 5
	GROW_CURVE_ANTI_STRIKE1       GrowCurveType = 6
	GROW_CURVE_ANTI_STRIKE2       GrowCurveType = 7
	GROW_CURVE_ANTI_STRIKE3       GrowCurveType = 8
	GROW_CURVE_STRIKE_HURT        GrowCurveType = 9
	GROW_CURVE_ELEMENT            GrowCurveType = 10
	GROW_CURVE_KILL_EXP           GrowCurveType = 11
	GROW_CURVE_DEFENSE            GrowCurveType = 12
	GROW_CURVE_ATTACK_BOMB        GrowCurveType = 13
	GROW_CURVE_HP_LITTLEMONSTER   GrowCurveType = 14
	GROW_CURVE_ELEMENT_MASTERY    GrowCurveType = 15
	GROW_CURVE_PROGRESSION        GrowCurveType = 16
	GROW_CURVE_DEFENDING          GrowCurveType = 17
	GROW_CURVE_MHP                GrowCurveType = 18
	GROW_CURVE_MATK               GrowCurveType = 19
	GROW_CURVE_TOWERATK           GrowCurveType = 20
	GROW_CURVE_HP_S5              GrowCurveType = 21
	GROW_CURVE_HP_S4              GrowCurveType = 22
	GROW_CURVE_HP_2               GrowCurveType = 23
	GROW_CURVE_ATTACK_2           GrowCurveType = 24
	GROW_CURVE_HP_ENVIRONMENT     GrowCurveType = 25
	GROW_CURVE_ATTACK_S5          GrowCurveType = 31
	GROW_CURVE_ATTACK_S4          GrowCurveType = 32
	GROW_CURVE_ATTACK_S3          GrowCurveType = 33
	GROW_CURVE_STRIKE_S5          GrowCurveType = 34
	GROW_CURVE_DEFENSE_S5         GrowCurveType = 41
	GROW_CURVE_DEFENSE_S4         GrowCurveType = 42
	GROW_CURVE_ATTACK_101         GrowCurveType = 1101
	GROW_CURVE_ATTACK_102         GrowCurveType = 1102
	GROW_CURVE_ATTACK_103         GrowCurveType = 1103
	GROW_CURVE_ATTACK_104         GrowCurveType = 1104
	GROW_CURVE_ATTACK_105         GrowCurveType = 1105
	GROW_CURVE_ATTACK_201         GrowCurveType = 1201
	GROW_CURVE_ATTACK_202         GrowCurveType = 1202
	GROW_CURVE_ATTACK_203         GrowCurveType = 1203
	GROW_CURVE_ATTACK_204         GrowCurveType = 1204
	GROW_CURVE_ATTACK_205         GrowCurveType = 1205
	GROW_CURVE_ATTACK_301         GrowCurveType = 1301
	GROW_CURVE_ATTACK_302         GrowCurveType = 1302
	GROW_CURVE_ATTACK_303         GrowCurveType = 1303
	GROW_CURVE_ATTACK_304         GrowCurveType = 1304
	GROW_CURVE_ATTACK_305         GrowCurveType = 1305
	GROW_CURVE_CRITICAL_101       GrowCurveType = 2101
	GROW_CURVE_CRITICAL_102       GrowCurveType = 2102
	GROW_CURVE_CRITICAL_103       GrowCurveType = 2103
	GROW_CURVE_CRITICAL_104       GrowCurveType = 2104
	GROW_CURVE_CRITICAL_105       GrowCurveType = 2105
	GROW_CURVE_CRITICAL_201       GrowCurveType = 2201
	GROW_CURVE_CRITICAL_202       GrowCurveType = 2202
	GROW_CURVE_CRITICAL_203       GrowCurveType = 2203
	GROW_CURVE_CRITICAL_204       GrowCurveType = 2204
	GROW_CURVE_CRITICAL_205       GrowCurveType = 2205
	GROW_CURVE_CRITICAL_301       GrowCurveType = 2301
	GROW_CURVE_CRITICAL_302       GrowCurveType = 2302
	GROW_CURVE_CRITICAL_303       GrowCurveType = 2303
	GROW_CURVE_CRITICAL_304       GrowCurveType = 2304
	GROW_CURVE_CRITICAL_305       GrowCurveType = 2305
	GROW_CURVE_ACTIVITY_ATTACK_1  GrowCurveType = 5201
	GROW_CURVE_ACTIVITY_HP_1      GrowCurveType = 5202
	GROW_CURVE_ACTIVITY_ATTACK_2  GrowCurveType = 5701
	GROW_CURVE_ACTIVITY_HP_2      GrowCurveType = 5702
	GROW_CURVE_ACTIVITY_DEFENSE_2 GrowCurveType = 570
)

func GrowCurveTypeString

func GrowCurveTypeString(s string) (GrowCurveType, error)

GrowCurveTypeString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func GrowCurveTypeValues

func GrowCurveTypeValues() []GrowCurveType

GrowCurveTypeValues returns all values of the enum

func (GrowCurveType) IsAGrowCurveType

func (i GrowCurveType) IsAGrowCurveType() bool

IsAGrowCurveType returns "true" if the value is listed in the enum definition. "false" otherwise

func (GrowCurveType) MarshalJSON

func (i GrowCurveType) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for GrowCurveType

func (GrowCurveType) MarshalText

func (i GrowCurveType) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for GrowCurveType

func (GrowCurveType) String

func (i GrowCurveType) String() string

func (*GrowCurveType) UnmarshalJSON

func (i *GrowCurveType) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for GrowCurveType

func (*GrowCurveType) UnmarshalText

func (i *GrowCurveType) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for GrowCurveType

type HomeWorldFurniture

type HomeWorldFurniture struct {
	Item
	SurfaceType string // FurnitureDeploySurfaceType
	RankLevel   uint32
}

func FindHomeWorldFurniture

func FindHomeWorldFurniture(id uint32) *HomeWorldFurniture

type IdCount

type IdCount struct {
	Id    uint32
	Count uint32
}

type Item

type Item struct {
	Id              uint32
	NameTextMapHash TextMapHash
	DescTextMapHash TextMapHash
	Icon            string
	ItemType        ItemType
	Weight          uint32
	Rank            uint32
	GadgetId        uint32
	Dropable        bool
	UseLevel        uint32
	GlobalItemLimit uint32
}

func (*Item) Name

func (i *Item) Name() string

type ItemType

type ItemType uint32
const (
	ITEM_NONE ItemType = iota
	ITEM_VIRTUAL
	ITEM_MATERIAL
	ITEM_RELIQUARY
	ITEM_WEAPON
	ITEM_DISPLAY
	ITEM_FURNITURE
)

func ItemTypeString

func ItemTypeString(s string) (ItemType, error)

ItemTypeString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func ItemTypeValues

func ItemTypeValues() []ItemType

ItemTypeValues returns all values of the enum

func (ItemType) IsAItemType

func (i ItemType) IsAItemType() bool

IsAItemType returns "true" if the value is listed in the enum definition. "false" otherwise

func (ItemType) MarshalJSON

func (i ItemType) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for ItemType

func (ItemType) MarshalText

func (i ItemType) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for ItemType

func (ItemType) String

func (i ItemType) String() string

func (*ItemType) UnmarshalJSON

func (i *ItemType) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for ItemType

func (*ItemType) UnmarshalText

func (i *ItemType) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for ItemType

type LoaderConfig

type LoaderConfig struct {
	Root      string
	ReadFile  func(root, name string) ([]byte, error)
	Languages []string
}

type ManualTextMap

type ManualTextMap struct {
	TextMapId                 string
	TextMapContentTextMapHash TextMapHash
	ParamTypes                []string
}

func FindManualTextMap

func FindManualTextMap(id string) *ManualTextMap

func (*ManualTextMap) Name

func (m *ManualTextMap) Name() string

type Material

type Material struct {
	Item
	MaterialType string // MaterialType
	StackLimit   uint32
	MaxUseCount  uint32
	RankLevel    uint32
	FoodQuality  string // FoodQualityType
}

func FindMaterial

func FindMaterial(id uint32) *Material

type Monster

type Monster struct {
	Creature
	MonsterName       string
	Type              string // MonsterType
	Affix             []uint32
	Equips            []uint32
	HpDrops           []*MonsterDrop
	KillDropId        uint32
	FeatureTagGroupId uint32
	DescribeId        uint32
}

func FindMonster

func FindMonster(id uint32) *Monster

func (*Monster) Curve

func (m *Monster) Curve(level uint32) *Curve

func (*Monster) Describe

func (m *Monster) Describe() *MonsterDescribe

type MonsterDescribe

type MonsterDescribe struct {
	Id               uint32
	NameTextMapHash  TextMapHash
	TitleId          uint32
	SpecialNameLabId uint32
	Icon             string
}

func FindMonsterDescribe

func FindMonsterDescribe(id uint32) *MonsterDescribe

func (*MonsterDescribe) Name

func (m *MonsterDescribe) Name() string

type MonsterDrop

type MonsterDrop struct {
	DropId    uint32
	HpPercent float64
}

type PlayerProp

type PlayerProp uint32
const (
	PROP_NONE                            PlayerProp = 0
	PROP_EXP                             PlayerProp = 1001
	PROP_BREAK_LEVEL                     PlayerProp = 1002
	PROP_SATIATION_VAL                   PlayerProp = 1003
	PROP_SATIATION_PENALTY_TIME          PlayerProp = 1004
	PROP_LEVEL                           PlayerProp = 4001
	PROP_LAST_CHANGE_AVATAR_TIME         PlayerProp = 10001
	PROP_MAX_SPRING_VOLUME               PlayerProp = 10002
	PROP_CUR_SPRING_VOLUME               PlayerProp = 10003
	PROP_IS_SPRING_AUTO_USE              PlayerProp = 10004
	PROP_SPRING_AUTO_USE_PERCENT         PlayerProp = 10005
	PROP_IS_FLYABLE                      PlayerProp = 10006
	PROP_IS_WEATHER_LOCKED               PlayerProp = 10007
	PROP_IS_GAME_TIME_LOCKED             PlayerProp = 10008
	PROP_IS_TRANSFERABLE                 PlayerProp = 10009
	PROP_MAX_STAMINA                     PlayerProp = 10010
	PROP_CUR_PERSIST_STAMINA             PlayerProp = 10011
	PROP_CUR_TEMPORARY_STAMINA           PlayerProp = 10012
	PROP_PLAYER_LEVEL                    PlayerProp = 10013
	PROP_PLAYER_EXP                      PlayerProp = 10014
	PROP_PLAYER_HCOIN                    PlayerProp = 10015
	PROP_PLAYER_SCOIN                    PlayerProp = 10016
	PROP_PLAYER_MP_SETTING_TYPE          PlayerProp = 10017
	PROP_IS_MP_MODE_AVAILABLE            PlayerProp = 10018
	PROP_PLAYER_WORLD_LEVEL              PlayerProp = 10019
	PROP_PLAYER_RESIN                    PlayerProp = 10020
	PROP_PLAYER_WAIT_SUB_HCOIN           PlayerProp = 10022
	PROP_PLAYER_WAIT_SUB_SCOIN           PlayerProp = 10023
	PROP_IS_ONLY_MP_WITH_PS_PLAYER       PlayerProp = 10024
	PROP_PLAYER_MCOIN                    PlayerProp = 10025
	PROP_PLAYER_WAIT_SUB_MCOIN           PlayerProp = 10026
	PROP_PLAYER_LEGENDARY_KEY            PlayerProp = 10027
	PROP_IS_HAS_FIRST_SHARE              PlayerProp = 10028
	PROP_PLAYER_FORGE_POINT              PlayerProp = 10029
	PROP_CUR_CLIMATE_METER               PlayerProp = 10035
	PROP_CUR_CLIMATE_TYPE                PlayerProp = 10036
	PROP_CUR_CLIMATE_AREA_ID             PlayerProp = 10037
	PROP_CUR_CLIMATE_AREA_CLIMATE_TYPE   PlayerProp = 10038
	PROP_PLAYER_WORLD_LEVEL_LIMIT        PlayerProp = 10039
	PROP_PLAYER_WORLD_LEVEL_ADJUST_CD    PlayerProp = 10040
	PROP_PLAYER_LEGENDARY_DAILY_TASK_NUM PlayerProp = 10041
	PROP_PLAYER_HOME_COIN                PlayerProp = 10042
	PROP_PLAYER_WAIT_SUB_HOME_COIN       PlayerProp = 10043
	PROP_IS_AUTO_UNLOCK_SPECIFIC_EQUIP   PlayerProp = 10044
	PROP_PLAYER_GCG_COIN                 PlayerProp = 10045
	PROP_PLAYER_WAIT_SUB_GCG_COIN        PlayerProp = 10046
	PROP_PLAYER_ONLINE_TIME              PlayerProp = 10047
	PROP_PLAYER_CAN_DIVE                 PlayerProp = 10048
	PROP_DIVE_MAX_STAMINA                PlayerProp = 10049
	PROP_DIVE_CUR_STAMINA                PlayerProp = 10050
)

func PlayerPropString

func PlayerPropString(s string) (PlayerProp, error)

PlayerPropString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func PlayerPropValues

func PlayerPropValues() []PlayerProp

PlayerPropValues returns all values of the enum

func (PlayerProp) IsAPlayerProp

func (i PlayerProp) IsAPlayerProp() bool

IsAPlayerProp returns "true" if the value is listed in the enum definition. "false" otherwise

func (PlayerProp) MarshalJSON

func (i PlayerProp) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for PlayerProp

func (PlayerProp) MarshalText

func (i PlayerProp) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for PlayerProp

func (PlayerProp) String

func (i PlayerProp) String() string

func (*PlayerProp) UnmarshalJSON

func (i *PlayerProp) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for PlayerProp

func (*PlayerProp) UnmarshalText

func (i *PlayerProp) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for PlayerProp

type PropValue

type PropValue struct {
	PropType FightProp
	Value    float64
}

type ProudSkill

type ProudSkill struct {
	BaseTalent
	ProudSkillId      uint32
	ProudSkillGroupId uint32
	Level             uint32
	ProudSkillType    uint32
	NameTextMapHash   TextMapHash
	DescTextMapHash   TextMapHash
	Icon              string
	CoinCost          uint32
	CostItems         []*IdCount
	Breaklevel        uint32
	ParamDescList     []TextMapHash
}

func FindProudSkill

func FindProudSkill(id, level uint32) *ProudSkill

func (*ProudSkill) Name

func (a *ProudSkill) Name() string

type ProudSkillOpen

type ProudSkillOpen struct {
	ProudSkillGroupId      uint32
	NeedAvatarPromoteLevel uint32
}

type ReactionType

type ReactionType uint32
const (
	ReactionNone                        ReactionType = 0
	ReactionExplode                     ReactionType = 1
	ReactionStream                      ReactionType = 2
	ReactionBurning                     ReactionType = 3
	ReactionBurned                      ReactionType = 4
	ReactionWet                         ReactionType = 5
	ReactionOvergrow                    ReactionType = 6
	ReactionMelt                        ReactionType = 7
	ReactionFreeze                      ReactionType = 8
	ReactionAntiFire                    ReactionType = 9
	ReactionRock                        ReactionType = 10
	ReactionSlowDown                    ReactionType = 11
	ReactionShock                       ReactionType = 12
	ReactionWind                        ReactionType = 13
	ReactionElectric                    ReactionType = 14
	ReactionFire                        ReactionType = 15
	ReactionSuperconductor              ReactionType = 16
	ReactionSwirlFire                   ReactionType = 17
	ReactionSwirlWater                  ReactionType = 18
	ReactionSwirlElectric               ReactionType = 19
	ReactionSwirlIce                    ReactionType = 20
	ReactionSwirlFireAccu               ReactionType = 21
	ReactionSwirlWaterAccu              ReactionType = 22
	ReactionSwirlElectricAccu           ReactionType = 23
	ReactionSwirlIceAccu                ReactionType = 24
	ReactionStickRock                   ReactionType = 25
	ReactionStickWater                  ReactionType = 26
	ReactionCrystallizeFire             ReactionType = 27
	ReactionCrystallizeWater            ReactionType = 28
	ReactionCrystallizeElectric         ReactionType = 29
	ReactionCrystallizeIce              ReactionType = 30
	ReactionFrozenBroken                ReactionType = 31
	ReactionStickGrass                  ReactionType = 32
	ReactionOverdose                    ReactionType = 33
	ReactionOverdoseElectric            ReactionType = 34
	ReactionOverdoseGrass               ReactionType = 35
	ReactionOvergrowMushroomFire        ReactionType = 36
	ReactionOvergrowMushroomElectric    ReactionType = 37
	ReactionPhlogistonSolidification    ReactionType = 38
	ReactionPhlogistonSolidificationEnd ReactionType = 39
	ReactionMoonShock                   ReactionType = 40
	ReactionMoonOvergrow                ReactionType = 41
	ReactionMoonCrystallizeWater        ReactionType = 42
)

func ReactionTypeString

func ReactionTypeString(s string) (ReactionType, error)

ReactionTypeString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func ReactionTypeValues

func ReactionTypeValues() []ReactionType

ReactionTypeValues returns all values of the enum

func (ReactionType) IsAReactionType

func (i ReactionType) IsAReactionType() bool

IsAReactionType returns "true" if the value is listed in the enum definition. "false" otherwise

func (ReactionType) MarshalJSON

func (i ReactionType) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for ReactionType

func (ReactionType) MarshalText

func (i ReactionType) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for ReactionType

func (ReactionType) String

func (i ReactionType) String() string

func (*ReactionType) UnmarshalJSON

func (i *ReactionType) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for ReactionType

func (*ReactionType) UnmarshalText

func (i *ReactionType) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for ReactionType

type Reliquary

type Reliquary struct {
	Item
	EquipType                  EquipType
	RankLevel                  uint32
	MainPropDepotId            uint32
	AppendPropDepotId          uint32
	AppendPropNum              uint32
	SetId                      uint32
	AddPropLevels              []uint32
	BaseConvExp                uint32
	MaxLevel                   uint32
	StoryId                    uint32
	DestroyRule                string // MaterialDestroyType
	DestroyReturnMaterial      []uint32
	DestroyReturnMaterialCount []uint32
	InitialLockState           uint32
}

func FindReliquary

func FindReliquary(id uint32) *Reliquary

func (*Reliquary) AppendProp

func (r *Reliquary) AppendProp(id uint32) *ReliquaryAffix

func (*Reliquary) Codex

func (r *Reliquary) Codex() *ReliquaryCodex

func (*Reliquary) Level

func (r *Reliquary) Level(level uint32) *ReliquaryLevel

func (*Reliquary) MainProp

func (r *Reliquary) MainProp(id uint32) *ReliquaryMainProp

func (*Reliquary) Set

func (r *Reliquary) Set() *ReliquarySet

type ReliquaryAffix

type ReliquaryAffix struct {
	Id        uint32
	DepotId   uint32
	GroupId   uint32
	PropType  FightProp
	PropValue float64
}

func (*ReliquaryAffix) Max

func (r *ReliquaryAffix) Max() *ReliquaryAffix

func (*ReliquaryAffix) Min

func (r *ReliquaryAffix) Min() *ReliquaryAffix

func (*ReliquaryAffix) Rolls

func (r *ReliquaryAffix) Rolls() []*ReliquaryAffix

type ReliquaryCodex

type ReliquaryCodex struct {
	Id        uint32
	SuitId    uint32
	Level     uint32
	CupId     uint32
	LeatherId uint32
	CapId     uint32
	FlowerId  uint32
	SandId    uint32
}

func (*ReliquaryCodex) Reliquary

func (r *ReliquaryCodex) Reliquary(typ EquipType) *Reliquary

func (*ReliquaryCodex) Set

func (r *ReliquaryCodex) Set() *ReliquarySet

type ReliquaryLevel

type ReliquaryLevel struct {
	Rank     uint32
	Level    uint32
	Exp      uint32
	AddProps []*PropValue
}

func (*ReliquaryLevel) Stat

func (r *ReliquaryLevel) Stat(prop FightProp) float64

type ReliquaryMainProp

type ReliquaryMainProp struct {
	Id          uint32
	PropDepotId uint32
	PropType    FightProp
	AffixName   string // ReliquaryMainAffixName
}

type ReliquarySet

type ReliquarySet struct {
	SetId         uint32
	SetIcon       string
	SetNeedNum    []uint32
	EquipAffixId  uint32
	DisableFilter uint32
	ContainsList  []uint32
	BagSortValue  uint32
	DungeonGroup  []uint32
	TextList      []uint32
}

func FindReliquarySet

func FindReliquarySet(id uint32) *ReliquarySet

func (*ReliquarySet) Affix

func (r *ReliquarySet) Affix(level uint32) *EquipAffix

func (*ReliquarySet) Codex

func (r *ReliquarySet) Codex(level uint32) *ReliquaryCodex

type TextMapHash

type TextMapHash uint32

func (TextMapHash) Lang

func (h TextMapHash) Lang(lang string) string

func (TextMapHash) String

func (h TextMapHash) String() string

type Weapon

type Weapon struct {
	Item
	WeaponType                 WeaponType
	RankLevel                  uint32
	SkillAffix                 []uint32
	AwakenMaterial             uint32
	WeaponProp                 []*WeaponProperty
	AwakenIcon                 string
	WeaponPromoteId            uint32
	StoryId                    uint32
	AwakenCosts                []uint32
	EnhanceRule                uint32
	DestroyRule                string // MaterialDestroyType
	DestroyReturnMaterial      []uint32
	DestroyReturnMaterialCount []uint32
	InitialLockState           uint32
}

func FindWeapon

func FindWeapon(id uint32) *Weapon

func (*Weapon) Affix

func (w *Weapon) Affix(level uint32) *EquipAffix

func (*Weapon) Codex

func (w *Weapon) Codex() *WeaponCodex

func (*Weapon) Curve

func (w *Weapon) Curve(level uint32) *Curve

func (*Weapon) Promote

func (w *Weapon) Promote(level uint32) *WeaponPromote

type WeaponCodex

type WeaponCodex struct {
	WeaponId         uint32
	IsDisuse         bool
	ShowOnlyUnlocked bool
}

func (*WeaponCodex) Weapon

func (w *WeaponCodex) Weapon() *Weapon

type WeaponPromote

type WeaponPromote struct {
	WeaponPromoteId     uint32
	PromoteLevel        uint32
	CostItems           []*IdCount
	CoinCost            uint32
	AddProps            []*PropValue
	UnlockMaxLevel      uint32
	RequiredPlayerLevel uint32
}

type WeaponProperty

type WeaponProperty struct {
	PropType  FightProp
	InitValue float64
	Type      GrowCurveType
}

type WeaponType

type WeaponType uint32
const (
	WEAPON_NONE WeaponType = iota
	WEAPON_SWORD_ONE_HAND
	WEAPON_CROSSBOW
	WEAPON_STAFF
	WEAPON_DOUBLE_DAGGER
	WEAPON_KATANA
	WEAPON_SHURIKEN
	WEAPON_STICK
	WEAPON_SPEAR
	WEAPON_SHIELD_SMALL
	WEAPON_CATALYST
	WEAPON_CLAYMORE
	WEAPON_BOW
	WEAPON_POLE
)

func WeaponTypeString

func WeaponTypeString(s string) (WeaponType, error)

WeaponTypeString retrieves an enum value from the enum constants string name. Throws an error if the param is not part of the enum.

func WeaponTypeValues

func WeaponTypeValues() []WeaponType

WeaponTypeValues returns all values of the enum

func (WeaponType) IsAWeaponType

func (i WeaponType) IsAWeaponType() bool

IsAWeaponType returns "true" if the value is listed in the enum definition. "false" otherwise

func (WeaponType) MarshalJSON

func (i WeaponType) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface for WeaponType

func (WeaponType) MarshalText

func (i WeaponType) MarshalText() ([]byte, error)

MarshalText implements the encoding.TextMarshaler interface for WeaponType

func (WeaponType) String

func (i WeaponType) String() string

func (*WeaponType) UnmarshalJSON

func (i *WeaponType) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface for WeaponType

func (*WeaponType) UnmarshalText

func (i *WeaponType) UnmarshalText(text []byte) error

UnmarshalText implements the encoding.TextUnmarshaler interface for WeaponType

Jump to